fSpecRes: fSpecRes

Description Usage Arguments Value Author(s) Examples

View source: R/ConvolutionFunction.R

Description

Function to resample based on gaussian convolution according to the spectral response of different satellite missions

Usage

1
fSpecRes(Wl = Wl, Ref = Ref, convol = "Gaussian", Satellite = "MODIS")

Arguments

Wl
Ref

numeric array: Reflectance

convol

Character: Type of convolution. Default is "Gaussian", alternative "Uniform": all the bands in the spectral range are equally weighted, User"

Satellite

Character: Satellite e.g. "MODIS", "LANDSAT", Default MODIS

Value

data frame with the central Wavelength and the result of the gaussian convolution (mean and standard deviation)

Author(s)

Tommaso Julitta, Mirco Migliavacca, Thomas Wutzler

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
data("reflOO")





#Extract the convolved values on reflectance according to MODIS bands


res<-fSpecRes(Wl=reflOO$Wl, Ref=reflOO$Ref, convol='Gaussian', Satellite='MODIS')


plot(reflOO$Wl, reflOO$Ref, ylim=c(0,0.7),xlim=c(400,900), type="l",xlab = "Wl [nm]", ylab= "Reflectance [-]")


points(res$CWl.v, res$RefConvol, col="red")





#Extract the convolved values on reflectance according to LANDSAT bands


res<-fSpecRes(Wl=reflOO$Wl, Ref=reflOO$Ref, convol='Gaussian', Satellite='LANDSAT')


points(res$CWl.v, res$RefConvol, col="green", pch=19)


legend("topleft",col=c("red","green"),pch=c(1,19),cex=1.2,legend=c("MODIS","LANDSAT"),box.col="white")


box()

tommasojulitta/FieldSpectroscopyDP documentation built on March 12, 2020, 1:42 p.m.